From aa78fde6a92f66b84d626e114d8b54a5fb6ece0c Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Wed, 14 Nov 2012 07:19:43 -0500
Subject: [PATCH] - Added function for IPv6 prefixes in multiserver mirror setups to nginx plugin.

---
 interface/web/help/support_message_edit.php |   38 +++++++++++++++++++++++---------------
 1 files changed, 23 insertions(+), 15 deletions(-)

diff --git a/interface/web/help/support_message_edit.php b/interface/web/help/support_message_edit.php
index f97bb88..c6e992f 100644
--- a/interface/web/help/support_message_edit.php
+++ b/interface/web/help/support_message_edit.php
@@ -1,17 +1,14 @@
 <?php
 
 //* Set the path to the form definition file.
-$tform_def_file = "form/support_message.tform.php";
+$tform_def_file = 'form/support_message.tform.php';
 
 //* include the basic application and configuration files
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-//* Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'help')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('help');
 
 //* Loading the templating and form classes
 $app->uses('tpl,tform,tform_actions');
@@ -21,28 +18,30 @@
 class page_action extends tform_actions {
 
 	//* Custom onSubmit Event handler
-	function onSubmit() {
+	function onSubmit()
+    {
 		global $app, $conf;
 		
 		//* If the current user is not the admin user
-		if($_SESSION["s"]["user"]["typ"] != 'admin') {
+		if($_SESSION['s']['user']['typ'] != 'admin') {
 			//* Set the admin as recipient
-			$this->dataRecord["recipient_id"] = 1;
+			$this->dataRecord['recipient_id'] = 1;
 		}
 		
-		// Set the sender_id field to the ID of the current user
-		$this->dataRecord["sender_id"] = $_SESSION["s"]["user"]["userid"];
+		//* Set the sender_id field to the ID of the current user
+		$this->dataRecord['sender_id'] = $_SESSION['s']['user']['userid'];
 		
 		//* call the onSubmit function of the parent class
 		parent::onSubmit();
 	}
 	
 	//* Custom onShow Event handler
-	function onShow() {
+	function onShow() 
+    {
 		global $app, $conf;
 
 		//* We do not want that messages get edited, so we switch to a 
-		//  read only template  if a existing message is loaded
+		//*  read only template  if a existing message is loaded
 		if($this->id > 0) {
 			$app->tform->formDef['tabs']['message']['template'] = 'templates/support_message_view.htm';
 		}
@@ -50,12 +49,21 @@
 		//* call the onShow function of the parent class
 		parent::onShow();
 	}
+	
+	function onAfterInsert() 
+    {
+		global $app, $conf;
+		
+		if($_SESSION['s']['user']['typ'] == 'admin') {
+			$app->db->query("UPDATE support_message SET sys_userid = ".$this->dataRecord['recipient_id']." WHERE support_message_id = ".$this->id);
+		}
+		
+	}
+	
 }
 
 //* Create the new page object
 $page = new page_action();
-
-
 
 //* Start the page rendering and action handling
 $page->onLoad();

--
Gitblit v1.9.1